@@ -1,6 +1,6 @@
 package Class::Meta::AccessorBuilder;
 
-# $Id: AccessorBuilder.pm 3787 2008-05-05 17:58:15Z david $
+# $Id: AccessorBuilder.pm 3863 2008-05-09 19:13:03Z david $
 
 =head1 NAME
 
@@ -14,10 +14,12 @@ Class::Meta::AccessorBuilder - Perl style accessor generation
   use Class::Meta::Type;
   use IO::Socket;
 
-  my $type = Class::Meta::Type->add( key     => 'io_socket',
-                                     builder => 'default',
-                                     desc    => 'IO::Socket object',
-                                     name    => 'IO::Socket Object' );
+  my $type = Class::Meta::Type->add(
+      key     => 'io_socket',
+      builder => 'default',
+      desc    => 'IO::Socket object',
+      name    => 'IO::Socket Object'
+  );
 
 =head1 DESCRIPTION
 
@@ -183,7 +185,7 @@ which determines what accessors, if any, are to be created.
 =item @checks
 
 A list of code references that validate the value of an attribute. These will
-be used in the set acccessor (mutator) to validate new attribute values.
+be used in the set accessor (mutator) to validate new attribute values.
 
 =back
 
@@ -191,7 +193,7 @@ be used in the set acccessor (mutator) to validate new attribute values.
 
 use strict;
 use Class::Meta;
-our $VERSION = '0.55';
+our $VERSION = '0.60';
 
 sub build_attr_get {
     UNIVERSAL::can($_[0]->package, $_[0]->name);
@@ -200,14 +202,14 @@ sub build_attr_get {
 sub build_attr_set { &build_attr_get }
 
 my $req_chk = sub {
-    $_[2]->class->handle_error("Attribute ", $_[2]->name, " must be defined")
+    $_[2]->class->handle_error('Attribute ', $_[2]->name, ' must be defined')
       unless defined $_[0];
 };
 
 my $once_chk = sub {
-    $_[2]->class->handle_error("Attribute ", $_[2]->name,
-                               " can only be set once")
-      if defined $_[1]->{$_[2]->name};
+    $_[2]->class->handle_error(
+        'Attribute ', $_[2]->name, ' can only be set once'
+    ) if defined $_[1]->{$_[2]->name};
 };
 
 sub build {
@@ -352,8 +354,7 @@ sub build {
          };
     } elsif ($attr->view == Class::Meta::TRUSTED) {
         my $real_sub = $sub;
-        # XXX Should we have an accessor for this?
-        my $trusted = $attr->class->{trusted};
+        my $trusted = $attr->class->trusted;
         $sub = sub {
              my $caller = caller;
              # Circumvent generated constructors.
@@ -377,10 +378,14 @@ sub build {
 1;
 __END__
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please send bug reports to <bug-class-meta@rt.cpan.org> or report them via the
-CPAN Request Tracker at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Meta>.
+This module is stored in an open repository at the following address:
+
+L<https://svn.kineticode.com/Class-Meta/trunk/>
+
+Patches against Class::Meta are welcome. Please send bug reports to
+<bug-class-meta@rt.cpan.org>.
 
 =head1 AUTHOR
 
